@@ -22,7 +22,7 @@ from samtranslator.region_configuration import RegionConfiguration
 from samtranslator.swagger.swagger import SwaggerEditor
 from samtranslator.model.intrinsics import is_intrinsic, fnSub
 from samtranslator.model.lambda_ import LambdaPermission
-from samtranslator.translator import logical_id_generator
+from samtranslator.translator.logical_id_generator import LogicalIdGenerator
 from samtranslator.translator.arn_generator import ArnGenerator
 from samtranslator.model.tags.resource_tagging import get_tag_list
 from samtranslator.utils.py27hash_fix import Py27Dict, Py27UniStr
@@ -31,13 +31,13 @@ LOG = logging.getLogger(__name__)
 
 _CORS_WILDCARD = "'*'"
 CorsProperties = namedtuple(
-    "_CorsProperties", ["AllowMethods", "AllowHeaders", "AllowOrigin", "MaxAge", "AllowCredentials"]
+    "CorsProperties", ["AllowMethods", "AllowHeaders", "AllowOrigin", "MaxAge", "AllowCredentials"]
 )
 # Default the Cors Properties to '*' wildcard and False AllowCredentials. Other properties are actually Optional
 CorsProperties.__new__.__defaults__ = (None, None, _CORS_WILDCARD, None, False)
 
 AuthProperties = namedtuple(
-    "_AuthProperties",
+    "AuthProperties",
     [
         "Authorizers",
         "DefaultAuthorizer",
@@ -50,7 +50,7 @@ AuthProperties = namedtuple(
 )
 AuthProperties.__new__.__defaults__ = (None, None, None, True, None, None, None)
 UsagePlanProperties = namedtuple(
-    "_UsagePlanProperties", ["CreateUsagePlan", "Description", "Quota", "Tags", "Throttle", "UsagePlanName"]
+    "UsagePlanProperties", ["CreateUsagePlan", "Description", "Quota", "Tags", "Throttle", "UsagePlanName"]
 )
 UsagePlanProperties.__new__.__defaults__ = (None, None, None, None, None, None)
 
@@ -181,8 +181,10 @@ class ApiGenerator(object):
         open_api_version=None,
         models=None,
         domain=None,
+        fail_on_warnings=None,
         description=None,
         mode=None,
+        api_key_source_type=None,
     ):
         """Constructs an API Generator class that generates API Gateway resources
 
@@ -231,10 +233,12 @@ class ApiGenerator(object):
         self.remove_extra_stage = open_api_version
         self.models = models
         self.domain = domain
+        self.fail_on_warnings = fail_on_warnings
         self.description = description
         self.shared_api_usage_plan = shared_api_usage_plan
         self.template_conditions = template_conditions
         self.mode = mode
+        self.api_key_source_type = api_key_source_type
 
     def _construct_rest_api(self):
         """Constructs and returns the ApiGateway RestApi.
@@ -275,6 +279,9 @@ class ApiGenerator(object):
         self._add_binary_media_types()
         self._add_models()
 
+        if self.fail_on_warnings:
+            rest_api.FailOnWarnings = self.fail_on_warnings
+
         if self.disable_execute_api_endpoint is not None:
             self._add_endpoint_extension()
 
@@ -294,6 +301,9 @@ class ApiGenerator(object):
         if self.mode:
             rest_api.Mode = self.mode
 
+        if self.api_key_source_type:
+            rest_api.ApiKeySourceType = self.api_key_source_type
+
         return rest_api
 
     def _add_endpoint_extension(self):
@@ -383,7 +393,7 @@ class ApiGenerator(object):
         if stage_name_prefix.isalnum():
             stage_logical_id = self.logical_id + stage_name_prefix + "Stage"
         else:
-            generator = logical_id_generator.LogicalIdGenerator(self.logical_id + "Stage", stage_name_prefix)
+            generator = LogicalIdGenerator(self.logical_id + "Stage", stage_name_prefix)
             stage_logical_id = generator.gen()
         stage = ApiGatewayStage(stage_logical_id, attributes=self.passthrough_resource_attributes)
         stage.RestApiId = ref(self.logical_id)
@@ -407,7 +417,7 @@ class ApiGenerator(object):
 
         return stage
 
-    def _construct_api_domain(self, rest_api):
+    def _construct_api_domain(self, rest_api, route53_record_set_groups):
         """
         Constructs and returns the ApiGateway Domain and BasepathMapping
         """
@@ -420,7 +430,7 @@ class ApiGenerator(object):
             )
 
         self.domain["ApiDomainName"] = "{}{}".format(
-            "ApiGatewayDomainName", logical_id_generator.LogicalIdGenerator("", self.domain.get("DomainName")).gen()
+            "ApiGatewayDomainName", LogicalIdGenerator("", self.domain.get("DomainName")).gen()
         )
 
         domain = ApiGatewayDomainName(self.domain.get("ApiDomainName"), attributes=self.passthrough_resource_attributes)
@@ -524,17 +534,23 @@ class ApiGenerator(object):
                     self.logical_id,
                     "HostedZoneId or HostedZoneName is required to enable Route53 support on Custom Domains.",
                 )
-            logical_id = logical_id_generator.LogicalIdGenerator(
+
+            logical_id_suffix = LogicalIdGenerator(
                 "", route53.get("HostedZoneId") or route53.get("HostedZoneName")
             ).gen()
-            record_set_group = Route53RecordSetGroup(
-                "RecordSetGroup" + logical_id, attributes=self.passthrough_resource_attributes
-            )
-            if "HostedZoneId" in route53:
-                record_set_group.HostedZoneId = route53.get("HostedZoneId")
-            if "HostedZoneName" in route53:
-                record_set_group.HostedZoneName = route53.get("HostedZoneName")
-            record_set_group.RecordSets = self._construct_record_sets_for_domain(self.domain)
+            logical_id = "RecordSetGroup" + logical_id_suffix
+
+            record_set_group = route53_record_set_groups.get(logical_id)
+            if not record_set_group:
+                record_set_group = Route53RecordSetGroup(logical_id, attributes=self.passthrough_resource_attributes)
+                if "HostedZoneId" in route53:
+                    record_set_group.HostedZoneId = route53.get("HostedZoneId")
+                if "HostedZoneName" in route53:
+                    record_set_group.HostedZoneName = route53.get("HostedZoneName")
+                record_set_group.RecordSets = []
+                route53_record_set_groups[logical_id] = record_set_group
+
+            record_set_group.RecordSets += self._construct_record_sets_for_domain(self.domain)
 
         return domain, basepath_resource_list, record_set_group
 
@@ -575,14 +591,14 @@ class ApiGenerator(object):
         return alias_target
 
     @cw_timer(prefix="Generator", name="Api")
-    def to_cloudformation(self, redeploy_restapi_parameters):
+    def to_cloudformation(self, redeploy_restapi_parameters, route53_record_set_groups):
         """Generates CloudFormation resources from a SAM API resource
 
         :returns: a tuple containing the RestApi, Deployment, and Stage for an empty Api.
         :rtype: tuple
         """
         rest_api = self._construct_rest_api()
-        domain, basepath_mapping, route53 = self._construct_api_domain(rest_api)
+        domain, basepath_mapping, route53 = self._construct_api_domain(rest_api, route53_record_set_groups)
         deployment = self._construct_deployment(rest_api)
 
         swagger = None
