@@ -27,6 +27,7 @@ class LambdaFunction(Resource):
         "CodeSigningConfigArn": PropertyType(False, is_str()),
         "ImageConfig": PropertyType(False, is_type(dict)),
         "Architectures": PropertyType(False, list_of(one_of(is_str(), is_type(dict)))),
+        "EphemeralStorage": PropertyType(False, is_type(dict)),
     }
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id), "arn": lambda self: fnGetAtt(self.logical_id, "Arn")}
@@ -80,6 +81,8 @@ class LambdaEventSourceMapping(Resource):
         "FunctionResponseTypes": PropertyType(False, is_type(list)),
         "SelfManagedEventSource": PropertyType(False, is_type(dict)),
         "FilterCriteria": PropertyType(False, is_type(dict)),
+        "AmazonManagedKafkaConfig": PropertyType(False, is_type(dict)),
+        "SelfManagedKafkaConfig": PropertyType(False, is_type(dict)),
     }
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id)}
@@ -94,6 +97,7 @@ class LambdaPermission(Resource):
         "SourceAccount": PropertyType(False, is_str()),
         "SourceArn": PropertyType(False, is_str()),
         "EventSourceToken": PropertyType(False, is_str()),
+        "FunctionUrlAuthType": PropertyType(False, is_str()),
     }
 
 
@@ -122,3 +126,12 @@ class LambdaLayerVersion(Resource):
     }
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id), "arn": lambda self: fnGetAtt(self.logical_id, "Arn")}
+
+
+class LambdaUrl(Resource):
+    resource_type = "AWS::Lambda::Url"
+    property_types = {
+        "TargetFunctionArn": PropertyType(True, one_of(is_str(), is_type(dict))),
+        "AuthType": PropertyType(True, is_str()),
+        "Cors": PropertyType(False, is_type(dict)),
+    }
